@@ -82,10 +82,6 @@ public:
 
     virtual ~CodesHandle() = default;
 
-    /// Retrieve binary size of the handled message.
-    /// @return Size of the message in bytes.
-    virtual size_t messageSize() const = 0;
-
     /// Check if a key is defined.
     /// @param key Name of the field that is checked to be defined.
     /// @return True if the field is defined.
@@ -196,13 +192,20 @@ public:
     /// @param value Value the field is supposed to be set on.
     virtual void forceSet(const std::string& key, Span<const float> value) = 0;
 
-    /// Returns the number of elements contained for a given key
+    /// Returns the number of elements contained for a given key.
     ///
     /// Can be used to determine if a field is storing a scalar or an array.
     /// @param key Name of the field that is supposed to be inspected.
-    /// @return For given scalars 1 is returned. For given arrays the size of the array is returned..
+    /// @return For given scalars 1 is returned. For given arrays the size of the array is returned.
     virtual size_t size(const std::string& key) const = 0;
 
+    /// Calls `string_length` on the accessor of a field and returns its value.
+    ///
+    /// @param key Name of the field that is supposed to be inspected.
+    /// @return Value of the `string_length` method of the underlying accessor of the key.
+    /// @see ecCodes documentation for more information.
+    virtual size_t length(const std::string& key) const = 0;
+
     /// Get the value of the key.
     ///
     /// High-level functionality:
@@ -273,6 +276,18 @@ public:
     virtual void copyInto(uint8_t* data, size_t size) const = 0;
 
 
+    /// Retrieve binary size of the handled message.
+    /// @return Size in bytes of the message.
+    virtual size_t messageSize() const = 0;
+
+    /// Return the pointer to the underlying buffer.
+    /// @return Contiguous array to the underlying buffer as a span.
+    ///         No data is copied or owned, lifetime is bound to this handle.
+    /// @see    messageSize()
+    /// @throws CodesException on any error returned from eccodes
+    virtual Span<const uint8_t> messageData() const = 0;
+
+
     /// Iterate keys in a GRIB2 or BUFR handle.
     ///
     /// @param flags Iterator flags to filter keys
