@@ -11,39 +11,32 @@
 /// @file   TypeDate.h
 /// @author Baudouin Raoult
 /// @author Tiago Quintino
+/// @author Emanuele Danovaro
 /// @date   April 2016
 
-#ifndef metkit_TypeDate_H
-#define metkit_TypeDate_H
+#pragma once
 
 #include "metkit/mars/Type.h"
 
-namespace metkit {
-namespace mars {
+namespace metkit::mars {
 
 //----------------------------------------------------------------------------------------------------------------------
 
 class TypeDate : public Type {
 
-public: // methods
+public:  // methods
 
-    TypeDate(const std::string &name, const eckit::Value& settings);
+    TypeDate(const std::string& name, const eckit::Value& settings);
 
-    virtual ~TypeDate();
+    ~TypeDate() noexcept override = default;
 
-private: // methods
-
-    virtual void print( std::ostream &out ) const;
-    virtual void expand(const MarsExpandContext& ctx, std::vector<std::string>& values) const;
-    virtual bool expand(const MarsExpandContext& ctx, std::string& value) const;
-
-    long by_;
+private:  // methods
 
+    void print(std::ostream& out) const override;
+    void pass2(MarsRequest& request) override;
+    bool expand(std::string& value, const MarsRequest& request) const override;
 };
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace mars
-} // namespace metkit
-
-#endif
+}  // namespace metkit::mars
