@@ -9,38 +9,33 @@
  */
 
 /// @file   TypeRange.h
-/// @author Baudouin Raoult
-/// @author Tiago Quintino
-/// @date   April 2016
+/// @author Emanuele Danovaro
+/// @date   February 2022
 
-#ifndef metkit_TypeRange_H
-#define metkit_TypeRange_H
+#pragma once
 
-#include "metkit/mars/TypeToByList.h"
+#include "metkit/mars/Type.h"
 
-namespace metkit {
-namespace mars {
+namespace metkit::mars {
+
+class StepRange;
 
 //----------------------------------------------------------------------------------------------------------------------
 
-class TypeRange : public TypeToByList {
+class TypeRange : public Type {
 
-public: // methods
+public:  // methods
 
-    TypeRange(const std::string &name, const eckit::Value& settings);
+    TypeRange(const std::string& name, const eckit::Value& settings);
 
-    virtual ~TypeRange();
+    ~TypeRange() noexcept override = default;
 
-private: // methods
-
-    virtual void print( std::ostream &out ) const;
-    virtual bool expand(const MarsExpandContext& ctx, std::string& value) const;
+private:  // methods
 
+    void print(std::ostream& out) const override;
+    bool expand(std::string& value, const MarsRequest& request) const override;
 };
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace mars
-} // namespace metkit
-
-#endif
+}  // namespace metkit::mars
